require("AnAL")

local lg = love.graphics

Fighter = {
    curAnim = nil,
    health = 100,
    fighter_name = "",
    keyDelay = 0.2,
    keys = {}
}

function Fighter:checkForHit(opponent)
    local modifier = 1
    local high_block = false;
    local low_block = false
    if self.state == "high_block" then
        high_block = true
        modifier = 0.2
    elseif self.state == "low_block" then
        low_block = true
        modifier = 0.2
    end
    if self.state == "stance" or high_block or low_block then
        if opponent.state == "high_strike_strong" then
            if not high_block then
                self.state = "hit"
                self.curAnim = self.moves.high.hit[math.random(5)]
            end
            self.health = self.health - math.ceil(10 * modifier)
            opponent.state = "stance"
        elseif opponent.state == "high_strike_weak" then
            if not high_block then
                self.state = "hit"
                self.curAnim = self.moves.high.hit[math.random(5)]
            end
            self.health = self.health - math.ceil(5 * modifier)
            opponent.state = "stance"
        elseif opponent.state == "low_strike_strong" then
            if not low_block then
                self.state = "hit"
                self.curAnim = self.moves.low.hit[math.random(2)]
            end
            self.health = self.health - math.ceil(10 * modifier)
            opponent.state = "stance"
        elseif opponent.state == "low_strike_weak" then
            if not low_block then
                self.state = "hit"
                self.curAnim = self.moves.low.hit[math.random(2)]
            end
            self.health = self.health - math.ceil(5 * modifier)
            opponent.state = "stance"
        end
    end
end

function Fighter:load(path)
    self.moves = {
        general = {
            eliminated = {newAnimation(lg.newImage(path .. "General/Eliminated1.png"), 512, 512, 0.1, 0),
                newAnimation(lg.newImage(path .. "General/Eliminated2.png"), 512, 512, 0.1, 0)},
            stance = newAnimation(lg.newImage(path .. "General/Stance.png"), 512, 512, 0.15, 0),
            taunt = newAnimation(lg.newImage(path .. "General/Taunt.png"), 512, 512, 0.15, 0),
            victory = newAnimation(lg.newImage(path .. "General/Victory.png"), 512, 512, 0.1, 0)
        },
        high = {
            block = newAnimation(lg.newImage(path .. "High/Block.png"), 512, 512, 0.5, 0),
            overheadBlock = newAnimation(lg.newImage(path .. "High/OverheadBlock.png"), 512, 512, 0.5, 0),
            hit = {newAnimation(lg.newImage(path .. "High/Hit1Nose.png"), 512, 512, 0.1, 0),
                newAnimation(lg.newImage(path .. "High/Hit2Jaw.png"), 512, 512, 0.1, 0),
                newAnimation(lg.newImage(path .. "High/Hit3Forehead.png"), 512, 512, 0.1, 0),
                newAnimation(lg.newImage(path .. "High/Hit4RightCheek.png"), 512, 512, 0.1, 0),
                newAnimation(lg.newImage(path .. "High/Hit5LeftCheek.png"), 512, 512, 0.1, 0)},
            strikeStrong = {newAnimation(lg.newImage(path .. "High/Strike1Strong.png"), 512, 512, 0.07, 0),
                newAnimation(lg.newImage(path .. "High/Strike2Strong.png"), 512, 512, 0.07, 0)},
            strikeWeak = {newAnimation(lg.newImage(path .. "High/Strike1Weak.png"), 512, 512, 0.07, 0),
                newAnimation(lg.newImage(path .. "High/Strike2Weak.png"), 512, 512, 0.07, 0)}
        },
        low = {
            block = newAnimation(lg.newImage(path .. "Low/Block.png"), 512, 512, 0.5, 0),
            hit = {newAnimation(lg.newImage(path .. "Low/HitRibs.png"), 512, 512, 0.15, 0),
                newAnimation(lg.newImage(path .. "Low/HitStomach.png"), 512, 512, 0.15, 0)},
            strikeStrong = {newAnimation(lg.newImage(path .. "Low/Strike1Strong.png"), 512, 512, 0.07, 0),
                newAnimation(lg.newImage(path .. "Low/Strike2Strong.png"), 512, 512, 0.07, 0)},
            strikeWeak = {newAnimation(lg.newImage(path .. "Low/Strike1Weak.png"), 512, 512, 0.07, 0),
                newAnimation(lg.newImage(path .. "Low/Strike2Weak.png"), 512, 512, 0.07, 0)}
        }
    }
end

function Fighter:keypressed(key)
    self.keyDelay = self.keyDelay + 0.2
    self.keys[#self.keys+1] = key
end

function Fighter:parseMove(opponent)
    if self.curAnim == self.moves.general.stance then
        if (self.keys[1] == "a" or self.keys[1] == "kp4") or (self.keys[2] == "a" or self.keys[2] == "kp4") then
            self.curAnim = self.moves.general.taunt
        elseif self.keys[1] == "w" or self.keys[1] == "kp8" then
            if self.keys[2] == "e" or self.keys[2] == "kp9" then
                if self.keys[3] == "e" or self.keys[3] == "kp9" then
                    self.curAnim = self.moves.high.strikeStrong[math.random(2)]
                    self.state = "high_strike_strong"
                else
                    self.curAnim = self.moves.high.strikeWeak[math.random(2)]
                    self.state = "high_strike_weak"
                end
            elseif self.keys[2] == "d" or self.keys[2] == "kp6" then
                self.state = "high_block"
                self.curAnim = self.moves.high.block
            end
        elseif self.keys[1] == "s" or self.keys[1] == "kp5" then
            if self.keys[2] == "e" or self.keys[2] == "kp9" then
                if self.keys[3] == "e" or self.keys[3] == "kp9" then
                    self.curAnim = self.moves.low.strikeStrong[math.random(2)]
                    self.state = "low_strike_strong"
                else
                    self.curAnim = self.moves.low.strikeWeak[math.random(2)]
                    self.state = "low_strike_weak"
                end
            elseif self.keys[2] == "d" or self.keys[2] == "kp6" then
                self.state = "low_block"
                self.curAnim = self.moves.low.block
            end
        end
    end
    self:checkForHit(opponent)
end

function Fighter:update(dt, opponent)
    self.keyDelay = self.keyDelay - dt
    if self.keyDelay <= 0 or #self.keys >= 3 then
        self:parseMove(opponent)
        self.keyDelay = 0.2
        if #self.keys > 0 then
            self.keys = {}
        end
    end
    if self.curAnim ~= self.moves.general.stance then
        if self.curAnim:getCurrentFrame() >= self.curAnim:getSize() then
            self.curAnim:reset()
            self.curAnim = self.moves.general.stance
            self.state = "stance"
        end
    end
    self.curAnim:update(dt)
end

function Fighter:draw()
    self.curAnim:draw(self.x, self.y, 0, self.dir, 1, self.curAnim:getWidth() * 0.5, self.curAnim:getHeight() * 0.5)
    if self.player == "one" then
        lg.print("Player 1: " .. self.health, 0, 0)
    end
    if self.player == "two" then
        lg.print("Player 2: " .. self.health, lg.getWidth() - 160, 0)
    end
end

function Fighter:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self
    return o
end